#[repr(transparent)]
pub struct Index(u32);
A tagged block index (MSB = chain status, lower 31 bits = position in the header file).

  • If MSB = 0, the block is in the main chain. In this case, the index is equal to the block height, as we store mainchain headers with canonical order.
  • If MSB = 1, the block is in a fork chain. In this case, the index is different from the height, as we store fork headers (in the fork file) in the order they are found.

Tuple Fields

0: u32

Implementations

Source

impl Index

const FORK_BIT: u32 = 2_147_483_648u32

Mask for the MSB

const INDEX_MASK: u32 = 2_147_483_647u32

Mask for the 31 lower bits

pub fn new(index: u32) -> Result<Self, FlatChainstoreError>

Create a new mainchain entry (MSB is zero)

pub fn new_fork(index: u32) -> Result<Self, FlatChainstoreError>

Create a new fork entry (MSB is set)

pub fn is_main_chain(&self) -> bool

Tells if this is a block in our main chain

pub fn index(&self) -> u32

Takes only the integer height of the block, without the tag

pub fn is_empty(&self) -> bool

Tells if this is an empty position (i.e., we haven’t written anything here yet, or this is the mainchain genesis index)